package org.apache.bcel.util;

import java.io.IOException;
import java.io.InputStream;
import org.apache.bcel.classfile.ClassParser;
import org.apache.bcel.classfile.JavaClass;
import org.apache.bcel.classfile.Utility;

/* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/AbstractClassPathRepository.class */
abstract class AbstractClassPathRepository implements Repository {
    private final ClassPath classPath;

    @Override // org.apache.bcel.util.Repository
    public abstract void clear();

    @Override // org.apache.bcel.util.Repository
    public abstract JavaClass findClass(String str);

    @Override // org.apache.bcel.util.Repository
    public abstract void removeClass(JavaClass javaClass);

    @Override // org.apache.bcel.util.Repository
    public abstract void storeClass(JavaClass javaClass);

    /* JADX INFO: Access modifiers changed from: package-private */
    public AbstractClassPathRepository(ClassPath classPath) {
        this.classPath = classPath;
    }

    @Override // org.apache.bcel.util.Repository
    public ClassPath getClassPath() {
        return this.classPath;
    }

    @Override // org.apache.bcel.util.Repository
    public JavaClass loadClass(Class<?> clazz) throws ClassNotFoundException {
        String className = clazz.getName();
        JavaClass repositoryClass = findClass(className);
        if (repositoryClass != null) {
            return repositoryClass;
        }
        String name = className;
        int i = name.lastIndexOf(46);
        if (i > 0) {
            name = name.substring(i + 1);
        }
        try {
            InputStream clsStream = clazz.getResourceAsStream(name + ".class");
            Throwable th = null;
            try {
                JavaClass loadClass = loadClass(clsStream, className);
                if (clsStream != null) {
                    if (0 != 0) {
                        try {
                            clsStream.close();
                        } catch (Throwable th2) {
                            th.addSuppressed(th2);
                        }
                    } else {
                        clsStream.close();
                    }
                }
                return loadClass;
            } finally {
            }
        } catch (IOException e) {
            return null;
        }
    }

    private JavaClass loadClass(InputStream inputStream, String className) throws ClassNotFoundException {
        if (inputStream != null) {
            try {
                ClassParser parser = new ClassParser(inputStream, className);
                JavaClass clazz = parser.parse();
                storeClass(clazz);
                return clazz;
            } catch (IOException e) {
                throw new ClassNotFoundException("Exception while looking for class " + className + ": " + e, e);
            }
        }
        throw new ClassNotFoundException("ClassRepository could not load " + className);
    }

    @Override // org.apache.bcel.util.Repository
    public JavaClass loadClass(String className) throws ClassNotFoundException {
        if (className == null || className.isEmpty()) {
            throw new IllegalArgumentException("Invalid class name " + className);
        }
        String className2 = Utility.pathToPackage(className);
        JavaClass clazz = findClass(className2);
        if (clazz != null) {
            return clazz;
        }
        try {
            InputStream inputStream = this.classPath.getInputStream(className2);
            Throwable th = null;
            try {
                try {
                    JavaClass loadClass = loadClass(inputStream, className2);
                    if (inputStream != null) {
                        if (0 != 0) {
                            try {
                                inputStream.close();
                            } catch (Throwable th2) {
                                th.addSuppressed(th2);
                            }
                        } else {
                            inputStream.close();
                        }
                    }
                    return loadClass;
                } finally {
                }
            } finally {
            }
        } catch (IOException e) {
            throw new ClassNotFoundException("Exception while looking for class " + className2 + ": " + e, e);
        }
    }
}
